==> hidef-0.1.2.tgz: hidef-0.1.2/frozenarray.h <==
/*
  +----------------------------------------------------------------------+
  | Hidef                                                                |
  +----------------------------------------------------------------------+
  | Copyright (c) 2008 The PHP Group                                     |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Authors: Gopal Vijayaraghavan <gopalv@php.net>                       |
  +----------------------------------------------------------------------+
*/

/* $Id: frozenarray.h 265172 2008-08-20 13:42:58Z gopalv $ */

#ifndef PHP_FROZENARRAY_H
#define PHP_FROZENARRAY_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "zend.h"

typedef struct {
	zend_object zo;
	zval *data;
} frozen_array_object;

void frozen_array_init(TSRMLS_D);
void frozen_array_shutdown(TSRMLS_D);

zval* frozen_array_unserialize(const char* filename TSRMLS_DC);
zval* frozen_array_wrap_zval(zval* src TSRMLS_DC);

zval* frozen_array_copy_zval_ptr(zval *dst, zval *src);
void frozen_array_free_zval_ptr(zval** val);

#define FROZEN_METHOD(func) PHP_METHOD(FrozenArray, func)
#define PHP_HIDEF_OBJECT_NAME "FrozenArray"

#endif /* PHP_FROZENARRAY_H */
/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim>600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> hidef-0.1.7.tgz: hidef-0.1.7/frozenarray.h <==
/*
  +----------------------------------------------------------------------+
  | Hidef                                                                |
  +----------------------------------------------------------------------+
  | Copyright (c) 2008 The PHP Group                                     |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Authors: Gopal Vijayaraghavan <gopalv@php.net>                       |
  +----------------------------------------------------------------------+
*/

/* $Id: frozenarray.h 310118 2011-04-10 18:46:19Z gopalv $ */

#ifndef PHP_FROZENARRAY_H
#define PHP_FROZENARRAY_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php_hidef.h"
#include "zend.h"

typedef struct {
	zend_object zo;
	zval *data;
} frozen_array_object;

void frozen_array_init(TSRMLS_D);
void frozen_array_shutdown(TSRMLS_D);

zval* frozen_array_unserialize(const char* filename TSRMLS_DC);
zval* frozen_array_wrap_zval(zval* src TSRMLS_DC);

zval* frozen_array_copy_zval_ptr(zval *dst, zval *src, int persistent TSRMLS_DC);
void frozen_array_free_zval_ptr(zval** val, int persistent TSRMLS_DC);

#define FROZEN_METHOD(func) PHP_METHOD(FrozenArray, func)
#define PHP_HIDEF_OBJECT_NAME "FrozenArray"

#endif /* PHP_FROZENARRAY_H */
/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim>600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
